﻿local addon = HealPoints
local L = LibStub("AceLocale-3.0"):GetLocale("HealPoints") --Get the localization for our addon

local profileDB; --HealPoints.db.char, set later

local options =
	{
		type = "group",
		args = {
			general = {
				name = L["HealPoints"],
				desc = L["HealPoints Configuration."],
				type = "group",
				args = {
					calc = {
						type = "execute",
						name = L["Calculator"],
						desc = L["Display the HealPoints calculator"],
						order = 9,
						func = function()
							HealPoints:ToggleCalculator();
						end,
					},

					tooltips ={
						type = "toggle",
						name = L["Values in tooltips"],
						desc = L["Toggles the display of HealPoints change in item tooltips."],
						order = 10,
						get = function(info)
							return profileDB.tooltips == 1;
						end,
						set = function(info, value)
							profileDB.tooltips = 1 - profileDB.tooltips;
						end
					},
					debug ={
						type = "toggle",
						name = L["Debug mode"],
						desc = L["Toggles the display of debug messages."],
						order = 11,
						get = function(info) return HealPoints:IsDebugging() end,
						set = function(info, value)
							HealPoints:SetDebugging(value);
						end
					},

					mvs ={
						type = "execute",
						name = L["Most valuable stats"],
						desc = L["Lists the most valuable stat ranking according to current gear and buffs."],
						order = 20,
						func = function()
							HealPoints:PrintMVS();
						end,
					},
					--[[
					bscan ={
					type = "execute",
					name = "Special item bonuses",
					desc = "Print special set/equip bonuses detected to the console.",
					order = 21,
					func = function()
					HealPoints:listScannedBonuses();
					end
					},--]]

					gemheader = {
						type = "header",
						name = L["Gem selector"],
						desc = "",
						order = 30,
						cmdHidden = true,
					},		
					bluegems ={
						type = "select",
						name = L["Blue Sockets"],
						desc = L["Select gem to be used for empty blue socket calculations."],
						order = 31,
						cmdHidden = true,
						width = "full",
						get = function() 
							return profileDB.gems.blueGem;
						end,
						set = function(t, v)
							HealPoints:ClearCache();
							profileDB.gems.blueGem = v;
						end,
						values = HealPointsGems.blueSocket,
					},
					redgems ={
						type = "select",
						name = L["Red Sockets"],
						desc = L["Select gem to be used for empty red socket calculations."],
						order = 32,
						cmdHidden = true,
						width = "full",
						get = function() 
							return profileDB.gems.redGem;
						end,
						set = function(t, v)
							HealPoints:ClearCache();
							profileDB.gems.redGem = v;
						end,
						values = HealPointsGems.redSocket,
					},
					yellowgems ={
						type = "select",
						name = L["Yellow Sockets"],
						desc = L["Select gem to be used for empty yellow socket calculations."],
						order = 33,
						cmdHidden = true,
						width = "full",
						get = function() 
							return profileDB.gems.yellowGem;
						end,
						set = function(t, v)
							HealPoints:ClearCache();
							profileDB.gems.yellowGem = v;
						end,
						values = HealPointsGems.yellowSocket,
					},
				},
			},
			tooltips = {
				type = "group",
				name = "Tooltip Options",
				desc = "Change HealPoints tooltip options",
				args = {
					ignoreGems = {
						type = "toggle",
						name = L["Ignore Gems"],
						desc = L["Ignore gems when comparing items"],
						order = 0,
						get = function(info) return profileDB.ignoreGemsInTooltipDiff end,
						set = function(info, value)
							profileDB.ignoreGemsInTooltipDiff = value
							TankPointsTooltips.ClearCache()
						end,
					},
					ignoreEnchants = {
						type = 'toggle',
						name = L["Ignore Enchants"],
						desc = L["Ignore enchants when comparing items"],
						order = 1,
						get = function(info) return profileDB.ignoreEnchantsInTooltipDiff end,
						set = function(info, value)
							profileDB.ignoreEnchantsInTooltipDiff = value
							TankPointsTooltips.ClearCache()
						end,
					},
					ignorePrismatic = {
						type = 'toggle',
						name = L["Ignore Prismatic"],
						desc = L["Igmore prismatic sockets when comparing items"],
						order = 2,
						get = function(info) return profileDB.ignorePrismaticInTooltipDiff end,
						set = function(info, value)
							profileDB.ignorePrismaticInTooltipDiff = value
							TankPointsTooltips.ClearCache()
						end,
					},

				}
			},
		},
	};

function addon:SetupOptions()
	addon:Debug("addon:SetupOptions()");

	--[[20101226 
			i don't know which RegisterOptionsTable method to use, it's not documented. 	
			i tried it both ways, and both seem to work. No guarantees that i'm supposed to use 
			one over the other though.
			
			i asked which is the correct one on the wowace forums 
				http://forums.wowace.com/showthread.php?p=313189
				AceConfig vs AceConfigRegistry :RegisterOptionsTable
	]]--
	--LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable(optionsTableRegistrationName, options)

	--Register options table	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("HealPoints", options, {"hp", "healpoints"} ); --/hp and /healpoints are both our slash commands

	-- Setup Blizzard option frames
	addon.optionsFrames = {}
	local aceConfigDialog = LibStub("AceConfigDialog-3.0");
	local rootNodeName = L["HealPoints"]; --we need to use the same localized parent caption because children are placed under a parent node by caption
	addon.optionsFrames.general  = aceConfigDialog:AddToBlizOptions("HealPoints", rootNodeName, nil,          "general") --options.args.general
	addon.optionsFrames.tooltips = aceConfigDialog:AddToBlizOptions("HealPoints", L["Tooltips"], rootNodeName, "tooltips") --options.args.tooltips

	addon.optionsFrames.general.default  = function() addon:SetDefaultGeneralOptions() end;
	addon.optionsFrames.tooltips.default = function() addon:SetDefaultTooltipsOptions() end;

	profileDB = addon.db.char;
end;

--Callback function to reset default General options
function addon:SetDefaultGeneralOptions()
	--called when user clicks "Restore Default" in general stats configuration pane
	--or from /hp general default
	--TODO

	LibStub("AceConfigRegistry-3.0"):NotifyChange("HealPoints");
	addon:Print(L["Restored general defaults"]);
end;

--Callback function to reset default Tooltip options
function addon:SetDefaultTooltipsOptions()
	--called when user clicks "Restore Default" in tooltip configuration pane
	--or from /hp tooltips default
	--TODO

	LibStub("AceConfigRegistry-3.0"):NotifyChange("HealPoints");
	addon:Print(L["Restored tooltip defaults"]);
end;